@@ -22,10 +22,10 @@ import (
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/pulumi/pulumi/pkg/v3/codegen"
-	"github.com/pulumi/pulumi/pkg/v3/codegen/hcl2"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/hcl2/model"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/hcl2/model/format"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/hcl2/syntax"
+	"github.com/pulumi/pulumi/pkg/v3/codegen/pcl"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/schema"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/util/contract"
 )
@@ -33,7 +33,7 @@ import (
 type generator struct {
 	// The formatter to use when generating code.
 	*format.Formatter
-	program *hcl2.Program
+	program *pcl.Program
 	// C# namespace map per package.
 	namespaces map[string]map[string]string
 	// C# codegen compatibility mode per package.
@@ -50,9 +50,9 @@ type generator struct {
 
 const pulumiPackage = "pulumi"
 
-func GenerateProgram(program *hcl2.Program) (map[string][]byte, hcl.Diagnostics, error) {
+func GenerateProgram(program *pcl.Program) (map[string][]byte, hcl.Diagnostics, error) {
 	// Linearize the nodes into an order appropriate for procedural code generation.
-	nodes := hcl2.Linearize(program)
+	nodes := pcl.Linearize(program)
 
 	// Import C#-specific schema info.
 	namespaces := make(map[string]map[string]string)
@@ -87,7 +87,7 @@ func GenerateProgram(program *hcl2.Program) (map[string][]byte, hcl.Diagnostics,
 	g.Formatter = format.NewFormatter(g)
 
 	for _, n := range nodes {
-		if r, ok := n.(*hcl2.Resource); ok && requiresAsyncInit(r) {
+		if r, ok := n.(*pcl.Resource); ok && requiresAsyncInit(r) {
 			g.asyncInit = true
 			break
 		}
@@ -138,14 +138,14 @@ func (g *generator) genComment(w io.Writer, comment syntax.Comment) {
 }
 
 // genPreamble generates using statements, class definition and constructor.
-func (g *generator) genPreamble(w io.Writer, program *hcl2.Program) {
+func (g *generator) genPreamble(w io.Writer, program *pcl.Program) {
 	// Accumulate other using statements for the various providers and packages. Don't emit them yet, as we need
 	// to sort them later on.
 	systemUsings := codegen.NewStringSet()
 	pulumiUsings := codegen.NewStringSet()
 	preambleHelperMethods := codegen.NewStringSet()
 	for _, n := range program.Nodes {
-		if r, isResource := n.(*hcl2.Resource); isResource {
+		if r, isResource := n.(*pcl.Resource); isResource {
 			pkg, _, _, _ := r.DecomposeToken()
 			if pkg != pulumiPackage {
 				namespace := namespaceName(g.namespaces[pkg], pkg)
@@ -207,12 +207,12 @@ func (g *generator) genPreamble(w io.Writer, program *hcl2.Program) {
 
 // genInitialize generates the declaration and the call to the async Initialize method, and also fills stack
 // outputs from the initialization result.
-func (g *generator) genInitialize(w io.Writer, nodes []hcl2.Node) {
+func (g *generator) genInitialize(w io.Writer, nodes []pcl.Node) {
 	g.Indented(func() {
 		g.Fgenf(w, "%svar dict = Output.Create(Initialize());\n", g.Indent)
 		for _, n := range nodes {
 			switch n := n.(type) {
-			case *hcl2.OutputVariable:
+			case *pcl.OutputVariable:
 				g.Fprintf(w, "%sthis.%s = dict.Apply(dict => dict[\"%s\"]);\n", g.Indent,
 					propertyName(n.Name()), makeValidIdentifier(n.Name()))
 			}
@@ -224,7 +224,7 @@ func (g *generator) genInitialize(w io.Writer, nodes []hcl2.Node) {
 }
 
 // genPostamble closes the method and the class and declares stack output statements.
-func (g *generator) genPostamble(w io.Writer, nodes []hcl2.Node) {
+func (g *generator) genPostamble(w io.Writer, nodes []pcl.Node) {
 	g.Indented(func() {
 		// Return outputs from Initialize if needed
 		if g.asyncInit {
@@ -234,7 +234,7 @@ func (g *generator) genPostamble(w io.Writer, nodes []hcl2.Node) {
 				g.Indented(func() {
 					for _, n := range nodes {
 						switch n := n.(type) {
-						case *hcl2.OutputVariable:
+						case *pcl.OutputVariable:
 							g.Fgenf(w, "%s{ \"%s\", %[2]s },\n", g.Indent, n.Name())
 						}
 					}
@@ -249,7 +249,7 @@ func (g *generator) genPostamble(w io.Writer, nodes []hcl2.Node) {
 		// Emit stack output properties
 		for _, n := range nodes {
 			switch n := n.(type) {
-			case *hcl2.OutputVariable:
+			case *pcl.OutputVariable:
 				g.genOutputProperty(w, n)
 			}
 		}
@@ -257,22 +257,22 @@ func (g *generator) genPostamble(w io.Writer, nodes []hcl2.Node) {
 	g.Fprint(w, "}\n")
 }
 
-func (g *generator) genNode(w io.Writer, n hcl2.Node) {
+func (g *generator) genNode(w io.Writer, n pcl.Node) {
 	switch n := n.(type) {
-	case *hcl2.Resource:
+	case *pcl.Resource:
 		g.genResource(w, n)
-	case *hcl2.ConfigVariable:
+	case *pcl.ConfigVariable:
 		g.genConfigVariable(w, n)
-	case *hcl2.LocalVariable:
+	case *pcl.LocalVariable:
 		g.genLocalVariable(w, n)
-	case *hcl2.OutputVariable:
+	case *pcl.OutputVariable:
 		g.genOutputAssignment(w, n)
 	}
 }
 
 // requiresAsyncInit returns true if the program requires awaits in the code, and therefore an asynchronous
 // method must be declared.
-func requiresAsyncInit(r *hcl2.Resource) bool {
+func requiresAsyncInit(r *pcl.Resource) bool {
 	if r.Options == nil || r.Options.Range == nil {
 		return false
 	}
@@ -281,7 +281,7 @@ func requiresAsyncInit(r *hcl2.Resource) bool {
 }
 
 // resourceTypeName computes the C# class name for the given resource.
-func (g *generator) resourceTypeName(r *hcl2.Resource) string {
+func (g *generator) resourceTypeName(r *pcl.Resource) string {
 	// Compute the resource type from the Pulumi type token.
 	pkg, module, member, diags := r.DecomposeToken()
 	contract.Assert(len(diags) == 0)
@@ -302,7 +302,7 @@ func (g *generator) resourceTypeName(r *hcl2.Resource) string {
 }
 
 // resourceArgsTypeName computes the C# arguments class name for the given resource.
-func (g *generator) resourceArgsTypeName(r *hcl2.Resource) string {
+func (g *generator) resourceArgsTypeName(r *pcl.Resource) string {
 	// Compute the resource type from the Pulumi type token.
 	pkg, module, member, diags := r.DecomposeToken()
 	contract.Assert(len(diags) == 0)
@@ -330,7 +330,7 @@ func (g *generator) functionName(tokenArg model.Expression) (string, string) {
 	tokenRange := tokenArg.SyntaxNode().Range()
 
 	// Compute the resource type from the Pulumi type token.
-	pkg, module, member, diags := hcl2.DecomposeToken(token, tokenRange)
+	pkg, module, member, diags := pcl.DecomposeToken(token, tokenRange)
 	contract.Assert(len(diags) == 0)
 	namespaces := g.namespaces[pkg]
 	rootNamespace := namespaceName(namespaces, pkg)
@@ -345,7 +345,7 @@ func (g *generator) functionName(tokenArg model.Expression) (string, string) {
 
 // argumentTypeName computes the C# argument class name for the given expression and model type.
 func (g *generator) argumentTypeName(expr model.Expression, destType model.Type) string {
-	schemaType, ok := hcl2.GetSchemaForType(destType.(model.Type))
+	schemaType, ok := pcl.GetSchemaForType(destType.(model.Type))
 	if !ok {
 		return ""
 	}
@@ -365,7 +365,7 @@ func (g *generator) argumentTypeName(expr model.Expression, destType model.Type)
 		qualifier = ""
 	}
 
-	pkg, _, member, diags := hcl2.DecomposeToken(token, tokenRange)
+	pkg, _, member, diags := pcl.DecomposeToken(token, tokenRange)
 	contract.Assert(len(diags) == 0)
 	module := g.tokenToModules[pkg](token)
 	namespaces := g.namespaces[pkg]
@@ -396,7 +396,7 @@ func (g *generator) makeResourceName(baseName, count string) string {
 	return fmt.Sprintf("$\"%s-{%s}\"", baseName, count)
 }
 
-func (g *generator) genResourceOptions(opts *hcl2.ResourceOptions) string {
+func (g *generator) genResourceOptions(opts *pcl.ResourceOptions) string {
 	if opts == nil {
 		return ""
 	}
@@ -438,7 +438,7 @@ func (g *generator) genResourceOptions(opts *hcl2.ResourceOptions) string {
 }
 
 // genResource handles the generation of instantiations of non-builtin resources.
-func (g *generator) genResource(w io.Writer, r *hcl2.Resource) {
+func (g *generator) genResource(w io.Writer, r *pcl.Resource) {
 	qualifiedMemberName := g.resourceTypeName(r)
 	argsName := g.resourceArgsTypeName(r)
 
@@ -507,7 +507,7 @@ func (g *generator) genResource(w io.Writer, r *hcl2.Resource) {
 	g.genTrivia(w, r.Definition.Tokens.GetCloseBrace())
 }
 
-func (g *generator) genConfigVariable(w io.Writer, v *hcl2.ConfigVariable) {
+func (g *generator) genConfigVariable(w io.Writer, v *pcl.ConfigVariable) {
 	if !g.configCreated {
 		g.Fprintf(w, "%svar config = new Config();\n", g.Indent)
 		g.configCreated = true
@@ -543,13 +543,13 @@ func (g *generator) genConfigVariable(w io.Writer, v *hcl2.ConfigVariable) {
 	g.Fgenf(w, ";\n")
 }
 
-func (g *generator) genLocalVariable(w io.Writer, v *hcl2.LocalVariable) {
+func (g *generator) genLocalVariable(w io.Writer, v *pcl.LocalVariable) {
 	// TODO(pdg): trivia
 	expr := g.lowerExpression(v.Definition.Value, v.Type())
 	g.Fgenf(w, "%svar %s = %.3v;\n", g.Indent, makeValidIdentifier(v.Name()), expr)
 }
 
-func (g *generator) genOutputAssignment(w io.Writer, v *hcl2.OutputVariable) {
+func (g *generator) genOutputAssignment(w io.Writer, v *pcl.OutputVariable) {
 	if g.asyncInit {
 		g.Fgenf(w, "%svar %s", g.Indent, makeValidIdentifier(v.Name()))
 	} else {
@@ -558,7 +558,7 @@ func (g *generator) genOutputAssignment(w io.Writer, v *hcl2.OutputVariable) {
 	g.Fgenf(w, " = %.3v;\n", g.lowerExpression(v.Value, v.Type()))
 }
 
-func (g *generator) genOutputProperty(w io.Writer, v *hcl2.OutputVariable) {
+func (g *generator) genOutputProperty(w io.Writer, v *pcl.OutputVariable) {
 	// TODO(pdg): trivia
 	g.Fgenf(w, "%s[Output(\"%s\")]\n", g.Indent, v.Name())
 	// TODO(msh): derive the element type of the Output from the type of its value.
